from datetime import timedelta, datetime
from airflow import DAG
from airflow.contrib.operators.bigquery_operator import BigQueryOperator
from airflow.contrib.operators.bigquery_check_operator import BigQueryCheckOperator

dag_args = {
    'owner': 'rebecca.vickery',
    'depends_on_past': False,
    'start_date': datetime(2020, 5, 31),
    'email': ['rebeccavickeryds@gmail.com'],
    'email_on_failure': True,
    'email_on_retry': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=3)}

dag = DAG(
    dag_id='covid_italy_daily',
    start_date=datetime(2020, 5, 31),
    default_args=dag_args,
    end_date=None,
    schedule_interval='0 9 * * *')

t1 = BigQueryCheckOperator(task_id='check_public_data_exists',
                           sql="""
                            select count(*) > 0
                            from bigquery-public-data.covid19_italy.data_by_region
                            where DATE(date) = '{{ ds }}'
                        """,
                           use_legacy_sql=False)

t2 = BigQueryOperator(
    task_id='load_public_data',
    use_legacy_sql=False,
    create_disposition='CREATE_IF_NEEDED',
    write_disposition='WRITE_TRUNCATE',
    allow_large_results=True,
    bigquery_conn_id='bigquery_default',
    time_partitioning={
        "type": 'DAY'
        },
    sql='''
    #standardSQL
            select date, 
    sum(total_confirmed_cases) as total_confirmed_cases
    from bigquery-public-data.covid19_italy.data_by_region
    where DATE(date) = '{{ ds }}'
    group by date
    ''',
    destination_dataset_table='sandbox-278915:airflow.covid_italy_daily_cases',
    dag=dag)

t1 >> t2



"""Testing basic BigQuery connections and the churn dataset."""

import datetime

from airflow import models
from airflow.providers.google.cloud.operators import bigquery
from airflow.providers.google.cloud.operators.bigquery import BigQueryCheckOperator


yesterday = datetime.datetime.combine(
    datetime.datetime.today() - datetime.timedelta(1),
    datetime.datetime.min.time())

default_dag_args = {
    # Setting start date as yesterday starts the DAG immediately when it is detected in the Cloud Storage bucket.
    'start_date': yesterday,
    'retries': 1,
}


with models.DAG('churn_data_test_2',
        schedule_interval=datetime.timedelta(days=1),
        default_args=default_dag_args) as dag:

    # Copied from Google Example to test connections
    task_default = bigquery.BigQueryInsertJobOperator(
        task_id='task_default_connection',
        configuration={
            "query": {
                "query": 'SELECT 1',
                "useLegacySql": False
            }
        }
    )
    task_explicit = bigquery.BigQueryInsertJobOperator(
        task_id='task_explicit_connection',
        gcp_conn_id='google_cloud_default',
        configuration={
            "query": {
                "query": 'SELECT 1',
                "useLegacySql": False
            }
        }
    )
    # Copied from Blog Post
    check_public = BigQueryCheckOperator(task_id='check_public_event_data',
                                         sql="""
                            select count(*) > 0
                            from bigquery-public-data.austin_bikeshare.bikeshare_trips
                        """,
                                         use_legacy_sql=False)

    # Checking the churn data
    check_private = BigQueryCheckOperator(task_id='check_churn_event_data',
                                          sql="""
                            select count(*) > 0
                            from churn-test-353716.socialnet7.event
                        """,
                                          location="us-west1",
                                          use_legacy_sql=False)


task_default >> task_explicit >> check_public >> check_private
